use ash::{
    vk::{ApplicationInfo, InstanceCreateInfo},
    Entry,
};

#[derive(Debug, Clone)]
pub struct VulkanInfo {
    pub gpu_names: Vec<String>,
}

// const NVIDIA_VENDOR_ID: u32 = 0x10de;

impl VulkanInfo {
    /// # Safety
    ///
    /// Dlopens the vulkan library, so this is inherently unsafe. Should be fine in
    /// most circumstances
    pub fn get() -> anyhow::Result<Self> {
        let entry = unsafe { Entry::load() }?;
        let instance = unsafe {
            entry.create_instance(
                &InstanceCreateInfo::default().application_info(&ApplicationInfo::default()),
                None,
            )
        }?;
        let gpu_names = unsafe { instance.enumerate_physical_devices() }?
            .into_iter()
            .filter_map(|d| {
                Some(
                    unsafe { instance.get_physical_device_properties(d) }
                        .device_name_as_c_str()
                        .ok()?
                        .to_string_lossy()
                        .to_string(),
                )
            })
            .collect();
        unsafe { instance.destroy_instance(None) };
        Ok(Self { gpu_names })
    }
}
